%define	oname OGRE

%define soname %(echo %{version} | cut -d. -f1,2)
%define libname %mklibname %{name} %{soname}
%define	develname %mklibname %{name} -d

Summary:	Object-Oriented Graphics Rendering Engine
Name:		ogre
Version:	14.2.6
Release:	%mkrel 1
License:	MIT
Group:		System/Libraries
URL:		https://www.ogre3d.org
Source0:	https://github.com/OGRECave/ogre/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:	https://github.com/ocornut/imgui/archive/v1.90.4.tar.gz
BuildRequires:	boost-devel
BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	freeimage-devel
BuildRequires:	libatomic-devel
BuildRequires:	ninja
BuildRequires:	swig
BuildRequires:	pkgconfig(assimp)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(egl)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(glesv2)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(pugixml)
BuildRequires:	pkgconfig(OIS)
BuildRequires:	pkgconfig(sdl2)
BuildRequires:	pkgconfig(tbb)
BuildRequires:	pkgconfig(tinyxml)
BuildRequires:	pkgconfig(vulkan)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xaw7)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(xrandr)
BuildRequires:	pkgconfig(xt)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(zziplib)

Provides:	bundled(imgui) = 1.90.4

%description
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented,
flexible 3D engine written in C++ designed to make it easier  and  more
intuitive for developers to produce games and demos utilising 3D hardware.
The class library abstracts all the details of using the underlying system
libraries like Direct3D and OpenGL and provides an interface based on world
objects and other intuitive classes.

%package -n %{libname}
Summary:	Libraries needed for programs using %{oname}
Group:		System/Libraries
Requires:	%{name} >= %{version}-%{release}

%description -n %{libname}
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented,
flexible 3D engine written in C++ designed to make it easier  and  more
intuitive for developers to produce games and demos utilising 3D hardware.
The class library abstracts all the details of using the underlying system
libraries like Direct3D and OpenGL and provides an interface based on world
objects and other intuitive classes.

%package -n %{develname}
Summary:	Development headers and libraries for writing programs using %{oname}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{develname}
Development headers and libraries for writing programs using %{oname}.

%prep
%autosetup -p1 -a1

# Fix location
sed -i -e 's,/dist-packages/,/site-packages/,g' Components/Python/CMakeLists.txt

%build
%cmake -GNinja \
    -DCMAKE_SKIP_RPATH=ON \
    -DIMGUI_DIR="$(pwd)/imgui-1.90.4" \
    -DOGRE_BUILD_DOCS=OFF \
    -DOGRE_BUILD_RENDERSYSTEM_GL=ON \
    -DOGRE_BUILD_RENDERSYSTEM_GL3PLUS=ON \
    -DOGRE_BUILD_RENDERSYSTEM_GLES2=ON \
    -DOGRE_BUILD_SAMPLES=OFF \
    -DOGRE_BUILD_TESTS=OFF \
    -DOGRE_BUILD_TOOLS=ON \
    -DOGRE_INSTALL_DOCS=OFF \
    -DOGRE_INSTALL_SAMPLES=OFF \
    -DOGRE_INSTALL_TOOLS=ON \
    -DOGRE_STATIC=OFF
%cmake_build

%install
%cmake_install

%files
%{_bindir}/OgreAssimpConverter
%{_bindir}/OgreMeshUpgrader
%{_bindir}/OgreXMLConverter
%{_bindir}/VRMLConverter
%{_datadir}/%{oname}-%{soname}/
%{python3_sitelib}/Ogre/

%files -n %{libname}
%{_libdir}/libOgre*.so.%{soname}
%dir %{_libdir}/%{oname}/
%{_libdir}/%{oname}/*.so.%{soname}

%files -n %{develname}
%{_libdir}/libOgre*.so
%{_libdir}/pkgconfig/%{oname}*.pc
%{_libdir}/%{oname}/*.so
%{_libdir}/%{oname}/cmake/
%{_includedir}/%{oname}/


%changelog
* Thu Jun 20 2024 wally <wally> 14.2.6-1.mga10
+ Revision: 2075789
- new version 14.2.6
- new lib major 14.2

* Wed Jun 19 2024 wally <wally> 1.9.1-18.mga10
+ Revision: 2075373
- rebuild for boost 1.85.0

* Fri Jan 12 2024 wally <wally> 1.9.1-17.mga10
+ Revision: 2030573
- rebuild for boost 1.84.0

* Wed Sep 27 2023 wally <wally> 1.9.1-16.mga10
+ Revision: 1991476
- rebuild for boost 1.83.0

* Sat Dec 24 2022 wally <wally> 1.9.1-15.mga9
+ Revision: 1926509
- rebuild for boost 1.81.0

* Sun Jul 03 2022 wally <wally> 1.9.1-14.mga9
+ Revision: 1867289
- rebuild for boost 1.79.0

* Fri Apr 01 2022 umeabot <umeabot> 1.9.1-13.mga9
+ Revision: 1839550
- Mageia 9 Mass Rebuild

* Sun Dec 19 2021 wally <wally> 1.9.1-12.mga9
+ Revision: 1762662
- rebuild for boost 1.78.0

* Thu Sep 09 2021 wally <wally> 1.9.1-11.mga9
+ Revision: 1744716
- rebuild for boost 1.77.0

* Fri May 14 2021 wally <wally> 1.9.1-10.mga9
+ Revision: 1722996
- rebuild for boost 1.76.0

* Thu Dec 31 2020 wally <wally> 1.9.1-9.mga8
+ Revision: 1666792
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 1.9.1-8.mga8
+ Revision: 1662034
- rebuild for boost 1.74.0

* Sat Dec 05 2020 luigiwalser <luigiwalser> 1.9.1-7.mga8
+ Revision: 1653177
- try to fix sysctl header with glibc 2.32

* Mon Jul 20 2020 wally <wally> 1.9.1-6.mga8
+ Revision: 1607400
- rebuild for zziplib 0.13.71

* Sun May 03 2020 wally <wally> 1.9.1-5.mga8
+ Revision: 1578088
- rebuild for boost 1.73.0

* Wed Feb 19 2020 umeabot <umeabot> 1.9.1-4.mga8
+ Revision: 1544858
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 1.9.1-3.mga8
+ Revision: 1483406
- rebuild for boost 1.72.0
- build with new cmake macros

* Sun Apr 21 2019 daviddavid <daviddavid> 1.9.1-2.mga7
+ Revision: 1394503
- add missing BR on pkgconfig(egl)

* Fri Nov 16 2018 akien <akien> 1.9.1-1.mga7
+ Revision: 1330221
- Version 1.9.1

* Fri Nov 16 2018 akien <akien> 1.9.0-22.mga7
+ Revision: 1330133
- Fix detection of aarch64 bitness
- Drop samples packages
- Don't build tests
- Ensure build of GL, GLES2 and GL3Plus subsystems
- Revert to 1.9.0 (r1184692), downstream users not ready for 1.10+ yet

* Tue Nov 13 2018 akien <akien> 1.11.3-1.mga7
+ Revision: 1329768
- Version 1.11.3

* Mon Oct 15 2018 daviddavid <daviddavid> 1.11.0-9.mga7
+ Revision: 1320541
- rebuild for new openexr 2.3.0

* Sun Sep 23 2018 umeabot <umeabot> 1.11.0-8.mga7
+ Revision: 1299963
- Mageia 7 Mass Rebuild

* Sun May 27 2018 wally <wally> 1.11.0-7.mga7
+ Revision: 1232425
- rebuild for openexr 2.2.1

* Mon May 14 2018 akien <akien> 1.11.0-6.mga7
+ Revision: 1229600
- Keep libOgreGLSupport.a, otherwise OgreTargets.cmake is broken

* Sun May 13 2018 akien <akien> 1.11.0-5.mga7
+ Revision: 1228827
- Build GLES2 RenderSystem too

* Sat May 12 2018 akien <akien> 1.11.0-4.mga7
+ Revision: 1228560
- Remove conflicts in ogre-data, those were Cauldron-only hiccups

* Fri May 11 2018 wally <wally> 1.11.0-3.mga7
+ Revision: 1228321
- loosen requires for data pkg in lib pkg

* Fri May 11 2018 akien <akien> 1.11.0-2.mga7
+ Revision: 1228319
- Fix conflict with noarch data in %%{libname}

* Fri May 11 2018 akien <akien> 1.11.0-1.mga7
+ Revision: 1228308
- Version 1.11.0

* Sat Jan 13 2018 wally <wally> 1.10.11-2.mga7
+ Revision: 1192555
- rebuild for new ilmbase

* Tue Jan 02 2018 akien <akien> 1.10.11-1.mga7
+ Revision: 1189843
- Version 1.10.11
- Don't package samples
- Add Python bindings

* Mon Dec 25 2017 wally <wally> 1.9.0-20.mga7
+ Revision: 1184692
- rebuild for new boost

* Tue Nov 21 2017 tv <tv> 1.9.0-19.mga7
+ Revision: 1178305
- rebuild for boost 1.65

* Sat Sep 16 2017 tv <tv> 1.9.0-18.mga7
+ Revision: 1154578
- rebuild with latest boost

* Sat Jul 30 2016 akien <akien> 1.9.0-17.mga6
+ Revision: 1044035
- Use pkgconfig for BRs, order alphabetically
- No longer build docs, they're 250 MB and no developers use distro-provided docs for such an engine

* Tue Feb 16 2016 umeabot <umeabot> 1.9.0-16.mga6
+ Revision: 961813
- Mageia 6 Mass Rebuild

* Sat Dec 26 2015 daviddavid <daviddavid> 1.9.0-15.mga6
+ Revision: 915205
- rebuild for new boost 1.60.0

* Fri Sep 25 2015 fwang <fwang> 1.9.0-14.mga6
+ Revision: 883432
- rebuild for new boost

* Sat Aug 22 2015 akien <akien> 1.9.0-13.mga6
+ Revision: 868020
- Add Fedora patch to improve dynlib lookup
- Rebuild for gcc 5.2.1

* Fri Jul 31 2015 sander85 <sander85> 1.9.0-12.mga6
+ Revision: 860105
- Rebuild for new boost

* Sun May 03 2015 akien <akien> 1.9.0-11.mga5
+ Revision: 821185
- Fix requires for -samples package
- Add Ogre prefix to SampleBrowser package

* Wed Oct 15 2014 umeabot <umeabot> 1.9.0-10.mga5
+ Revision: 748020
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.9.0-9.mga5
+ Revision: 683165
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Wed Aug 27 2014 akien <akien> 1.9.0-8.mga5
+ Revision: 668820
- Rebuild for new tbb

* Wed Aug 27 2014 akien <akien> 1.9.0-7.mga5
+ Revision: 668596
- Add optional tbb, tinyxml and doxygen buildrequires
+ fwang <fwang>
- update file list

* Tue Aug 26 2014 fwang <fwang> 1.9.0-6.mga5
+ Revision: 667771
- fix build
+ wally <wally>
- fix license (upstream switched to MIT in 1.7)

* Sun Mar 23 2014 akien <akien> 1.9.0-5.mga5
+ Revision: 606732
- Add conflicts required by moving the libraries in 1.8.0-3

* Sun Mar 23 2014 akien <akien> 1.9.0-4.mga5
+ Revision: 606722
- Obsolete previous naming convention

* Sun Mar 23 2014 akien <akien> 1.9.0-3.mga5
+ Revision: 606672
- Libify the samples
- Continue libification of OGRE libraries
- Fix %%libname to use the actual SONAME

* Tue Mar 18 2014 akien <akien> 1.9.0-2.mga5
+ Revision: 605133
- Revert a change that broke %%libname

* Tue Mar 18 2014 akien <akien> 1.9.0-1.mga5
+ Revision: 605119
- New version 1.9.0
- Includes documentation in a ogre-doc package

* Wed Feb 05 2014 wally <wally> 1.8.1-7.mga5
+ Revision: 583629
- rebuild for new boost

* Sat Oct 19 2013 umeabot <umeabot> 1.8.1-6.mga4
+ Revision: 531646
- Mageia 4 Mass Rebuild

* Wed Aug 07 2013 wally <wally> 1.8.1-5.mga4
+ Revision: 464418
- make lib pkg to require main pkg (for RenderSystem_GL.so)

* Tue Jul 09 2013 fwang <fwang> 1.8.1-4.mga4
+ Revision: 451658
- rebuild for new boost

* Thu Apr 11 2013 barjac <barjac> 1.8.1-3.mga3
+ Revision: 409505
- rebuild for boost-1.53

* Sun Jan 13 2013 umeabot <umeabot> 1.8.1-2.mga3
+ Revision: 361811
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Dec 26 2012 juancho <juancho> 1.8.1-1.mga3
+ Revision: 335289
- Updated to 0.8.1

* Thu Dec 20 2012 fwang <fwang> 1.8.0-3.mga3
+ Revision: 332956
- rebuild for new boost

* Tue Jul 31 2012 fwang <fwang> 1.8.0-2.mga3
+ Revision: 276848
- fix more linkage
- build verbose makefile
- fix linkage
- rebuild for new boost

* Thu Jun 14 2012 juancho <juancho> 1.8.0-1.mga3
+ Revision: 260632
- Removed old and unneeded Obsoletes
- Updated to 1.8.0

* Wed May 30 2012 fwang <fwang> 1.7.4-2.mga3
+ Revision: 250048
- rebuild for new boost

* Sat Feb 04 2012 juancho <juancho> 1.7.4-1.mga2
+ Revision: 204406
- Updated to 1.7.4

* Mon Nov 28 2011 fwang <fwang> 1.7.3-3.mga2
+ Revision: 173538
- rebuild for new boost
- rebuild for new boost

* Wed Jun 22 2011 fwang <fwang> 1.7.3-1.mga2
+ Revision: 111904
- new version 1.7.3

* Mon Feb 28 2011 supp <supp> 1.7.2-1.mga1
+ Revision: 61412
- imported package ogre

